<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU" sourcelanguage="ru_RU">
<context>
    <name>AboutDlg</name>
    <message>
        <location filename="aboutui.ui" line="14"/>
        <source>About GPSBabel</source>
        <translation>О GPSBabel</translation>
    </message>
    <message>
        <location filename="aboutui.ui" line="74"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:600;&quot;&gt;$appname$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;$babelfeversion$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Copyright (C) 2009 Robert Lipe&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;GUI designed and contributed by  S. Khai Mong&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;LGPL Crystal Icons by Alvarado Coehlo&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;(Using backend $babelversion$)&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;$upgradetestmode$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;This program is free software; you can redistribute it and/or  modify it under the terms of the GNU General Public License as  published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111 USA&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:600;&quot;&gt;$appname$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;$babelfeversion$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Copyright (C) 2009 Robert Lipe&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;GUI разработан S. Khai Mong&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;LGPL Crystal Icons - Alvarado Coehlo&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;(Используется gpsbabel версии $babelversion$)&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;$upgradetestmode$&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Это свободное программное обеспечение; вы можете его передавать и/или изменять согласно условиям лицензии GNU General Public License опубликованной Free Software Foundation; необходимо использовать либо Лицензию версии 2,либо выше (по вашему выбору).&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Эта программа распространяется с надеждой, что она будет полезна, но БЕЗ КАКИХ-ЛИБО ГАРАНТИЙ; Для более подробной информации ознакомьтесь с GNU General Public License.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;Вы должны получить копию GNU General Public License вместе с программой; если вы ее не получили напишите в Free Software Foundation, Inc., по адресу: 59 Temple Place - Suite 330, Boston, MA 02111 USA&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;DejaVu Sans&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>AdvUi</name>
    <message>
        <location filename="advui.ui" line="14"/>
        <source>Global Options</source>
        <translation>Глобальные настройки</translation>
    </message>
    <message>
        <location filename="advui.ui" line="20"/>
        <source>Create smart shortened names. </source>
        <translation>Создание сокращенных имен. </translation>
    </message>
    <message>
        <location filename="advui.ui" line="23"/>
        <source>Synthesize short names</source>
        <translation>Синтезировать короткие имена</translation>
    </message>
    <message>
        <location filename="advui.ui" line="33"/>
        <source>Convert character set encoding between input and output</source>
        <translation>Преобразование кодировок между входом и выходом</translation>
    </message>
    <message>
        <location filename="advui.ui" line="36"/>
        <source>Enable character set transformation</source>
        <translation>Включить преобразование кодировок</translation>
    </message>
    <message>
        <location filename="advui.ui" line="43"/>
        <source>Preview in Google Maps</source>
        <translation>Просмотр в Google Maps</translation>
    </message>
    <message>
        <location filename="advui.ui" line="52"/>
        <source>Debugging diagnostics.  
Higher number provides more deitaled diagnostics.</source>
        <translation>Отладочная диагностика.  
Чем выше номер, тем больше деталей.</translation>
    </message>
    <message>
        <location filename="advui.ui" line="57"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="advui.ui" line="62"/>
        <source>0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="advui.ui" line="67"/>
        <source>1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="advui.ui" line="72"/>
        <source>2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="advui.ui" line="77"/>
        <source>3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="advui.ui" line="82"/>
        <source>4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="advui.ui" line="87"/>
        <source>5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="advui.ui" line="92"/>
        <source>6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="advui.ui" line="97"/>
        <source>7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="advui.ui" line="102"/>
        <source>8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="advui.ui" line="107"/>
        <source>9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="advui.ui" line="115"/>
        <source>Debugging Diagnostics</source>
        <translation>Отладочная диагностика</translation>
    </message>
    <message>
        <location filename="advui.ui" line="139"/>
        <source>Set all format input/output options to default values</source>
        <translation>Установить все параметры входных и выходных форматов в значения по умолчанию</translation>
    </message>
    <message>
        <location filename="advui.ui" line="142"/>
        <source>Default Format Options</source>
        <translation>Параметры по умолчанию</translation>
    </message>
</context>
<context>
    <name>Donate</name>
    <message>
        <location filename="donate.ui" line="32"/>
        <source>Support GPSBabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="donate.ui" line="47"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Lucida Grande&apos;; font-size:13pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;GPSBabel is free software built and supported by volunteers. It consumes vast amounts of time to create and support the software as well as money for mapping programs, GPS receivers, and development fixtures. Please see how you can &lt;a href=&quot;http://www.gpsbabel.org&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;contribute time or via PayPal (no account needed) or Google Checkout.&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="donate.ui" line="61"/>
        <source>&lt;p&gt;Of course, if you&apos;ve already contributed  to the project or you just can&apos;t help the project, please check the box below to never see this message again.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="donate.ui" line="71"/>
        <source>Never show this message again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="donate.ui" line="93"/>
        <source>No, Thanks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="donate.ui" line="100"/>
        <source>Contribute</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileDlgManager</name>
    <message>
        <location filename="optionsdlg.cpp" line="70"/>
        <source>Select input file</source>
        <translation>Выберите входной файл</translation>
    </message>
    <message>
        <location filename="optionsdlg.cpp" line="75"/>
        <source>Select output file</source>
        <translation>Выберите выходной файл</translation>
    </message>
</context>
<context>
    <name>FilterDialog</name>
    <message>
        <location filename="filterdlg.cpp" line="41"/>
        <source>Tracks</source>
        <translation>Треки</translation>
    </message>
    <message>
        <location filename="filterdlg.cpp" line="44"/>
        <source>Waypoints</source>
        <translation>Маршрутные точки</translation>
    </message>
    <message>
        <location filename="filterdlg.cpp" line="47"/>
        <source>Routes &amp; Tracks</source>
        <translation>Маршруты и Треки</translation>
    </message>
    <message>
        <location filename="filterdlg.cpp" line="50"/>
        <source>Miscellaneous</source>
        <translation>Прочие</translation>
    </message>
    <message>
        <location filename="filterdlg.cpp" line="104"/>
        <source>Are you sure you want to reset all filter options to default values?</source>
        <translation>Cбросить все настройки фильтра в значения по умолчанию?</translation>
    </message>
</context>
<context>
    <name>FilterDlg</name>
    <message>
        <location filename="filterui.ui" line="14"/>
        <source>Data Filters</source>
        <translation>Фильтр данных</translation>
    </message>
    <message>
        <location filename="filterui.ui" line="17"/>
        <source>Data filters process and transform the data between input and output files or devices. </source>
        <translation>Фильтр позволяет обработать и преобразовать данные, подающиеся на вход.</translation>
    </message>
    <message>
        <location filename="filterui.ui" line="72"/>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <location filename="filterui.ui" line="83"/>
        <source>Reset</source>
        <translation>Сброс</translation>
    </message>
</context>
<context>
    <name>GMapDialog</name>
    <message>
        <location filename="gmapdlg.cpp" line="55"/>
        <source>meters</source>
        <translation>метров</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="64"/>
        <source>feet</source>
        <translation>футов</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="68"/>
        <source>miles</source>
        <translation>миль</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="71"/>
        <source>Length: %1 %2
  %3 %4</source>
        <translation>Протяженность: %1 %2
  %3 %4</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="81"/>
        <source>Lat: %1</source>
        <translation>Широта: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="82"/>
        <source>Lng: %1</source>
        <translation>Долгота: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="84"/>
        <source>Desc: %1</source>
        <translation>Описание: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="86"/>
        <source>Cmt: %1</source>
        <translation>Комментарий: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="88"/>
        <source>Ele: %1</source>
        <translation>Высота: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="118"/>
        <source>Start: %1</source>
        <translation>Начало: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="120"/>
        <source>Stop: %1</source>
        <translation>Конец: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="123"/>
        <source>Points: %1</source>
        <translation>Точек: %1</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="149"/>
        <source>Waypoints</source>
        <translation>Маршрутные точки</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="164"/>
        <source>Tracks</source>
        <translation>Треки</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="179"/>
        <source>Routes</source>
        <translation>Маршруты</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="521"/>
        <source>Show All Waypoints</source>
        <translation>Показать все маршрутные точки</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="522"/>
        <source>Hide All Waypoints</source>
        <translation>Скрыть все маршрутные точки</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="523"/>
        <location filename="gmapdlg.cpp" line="531"/>
        <location filename="gmapdlg.cpp" line="539"/>
        <source>Expand All</source>
        <translation>Развернуть все</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="524"/>
        <location filename="gmapdlg.cpp" line="532"/>
        <location filename="gmapdlg.cpp" line="540"/>
        <source>Collapse All</source>
        <translation>Свернуть все</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="529"/>
        <source>Show All Routes</source>
        <translation>Показать все маршруты</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="530"/>
        <source>Hide All Routes</source>
        <translation>Скрыть все маршруты</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="537"/>
        <source>Show All Tracks</source>
        <translation>Показать все треки</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="538"/>
        <source>Hide All Tracks</source>
        <translation>Скрыть все треки</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="545"/>
        <source>Show Only This Waypoint</source>
        <translation>Показать только эту маршрутную точку</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="551"/>
        <source>Show Only This Track</source>
        <translation>Показать только этот трек</translation>
    </message>
    <message>
        <location filename="gmapdlg.cpp" line="557"/>
        <source>Show Only This Route</source>
        <translation>Показать только этот маршрут</translation>
    </message>
</context>
<context>
    <name>GMapDlg</name>
    <message>
        <location filename="gmapui.ui" line="14"/>
        <source>Dialog</source>
        <translation>Диалог</translation>
    </message>
    <message>
        <location filename="gmapui.ui" line="47"/>
        <source>Copy to Clipboard</source>
        <translation>Копировать в буфер</translation>
    </message>
    <message>
        <location filename="gmapui.ui" line="50"/>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwinui.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Главное Окно</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="21"/>
        <source>Input </source>
        <translation>Вход</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="41"/>
        <source>If selected, input is from a file.</source>
        <translation>Если выбрано, то входные данные будут браться из файла.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="44"/>
        <location filename="mainwinui.ui" line="428"/>
        <location filename="mainwinui.ui" line="632"/>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="57"/>
        <source>If selected, input is from a device or GPS unit</source>
        <translation>Если выбрано, входные данные будут браться с устройства или GPS приемника</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="60"/>
        <location filename="mainwinui.ui" line="444"/>
        <source>Device</source>
        <translation>Устройство</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="89"/>
        <location filename="mainwinui.ui" line="473"/>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="96"/>
        <source>Input data format</source>
        <translation>Формат входных данных</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="103"/>
        <source>Character encoding of input</source>
        <translation>Кодировка входных данных</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="127"/>
        <source>Browse for one or more input files. </source>
        <translation>Выберите один или более входных файлов.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="130"/>
        <source>File Name(s)</source>
        <translation>Входные файлы</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="162"/>
        <location filename="mainwinui.ui" line="543"/>
        <source>Device Name:</source>
        <translation>Имя устройства:</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="169"/>
        <source>Name of port to which input device is connected</source>
        <translation>Порт к которому подключено входное устройство</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="200"/>
        <source>Options for the selected input format. </source>
        <translation>Параметры выбранного входного формата.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="203"/>
        <location filename="mainwinui.ui" line="584"/>
        <source>Options</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="218"/>
        <source>Translation Options</source>
        <translation>Параметры конвертации</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="227"/>
        <location filename="mainwinui.ui" line="270"/>
        <location filename="mainwinui.ui" line="310"/>
        <source>-</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="237"/>
        <source>If selected, translate waypoints.</source>
        <translation>Если выбрано, конвертируются маршрутные точки.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="240"/>
        <source>Waypoints</source>
        <translation>Маршрутные точки</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="277"/>
        <source>If selected, translate routes.</source>
        <translation>Если выбрано, конвертируются маршруты.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="280"/>
        <source>Routes</source>
        <translation>Маршруты</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="317"/>
        <source>If selected, translate tracks.</source>
        <translation>Если выбрано, конвертируются треки.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="320"/>
        <source>Tracks</source>
        <translation>Треки</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="356"/>
        <source>Data Filters between input and output</source>
        <translation>Фильтр данных между входом и выходом</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="359"/>
        <source>Filters</source>
        <translation>Фильтры</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="392"/>
        <source>More translation options. </source>
        <translation>Дополнительные параметры конвертации.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="395"/>
        <source>More Options</source>
        <translation>Дополнительно</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="405"/>
        <source>Output</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="425"/>
        <source>If selected, output is to a file. </source>
        <translation>Если выбрано, результат будет направлен в файл. </translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="441"/>
        <source>If selected, output is to a device or GPS unit</source>
        <translation>Если выбрано, результат будет направлен на устройство или GPS приемник</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="480"/>
        <source>Output data format.</source>
        <translation>Формат выходных данных.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="487"/>
        <source>Character encoding of output</source>
        <translation>Кодировка выходных данных</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="508"/>
        <source>Browse for an output file name. </source>
        <translation>Выберите имя выходного файла.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="511"/>
        <source>File Name</source>
        <translation>Имя файла</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="550"/>
        <source>Name of port to which output device is connected</source>
        <translation>Порт к которому подключено выходное устройство</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="581"/>
        <source>Options for the selected output format. </source>
        <translation>Параметры выбранного выходного формата.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="605"/>
        <source>Output of GPSBabel translation process. </source>
        <translation>Выполняется конвертация GPSBabel.</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="639"/>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="655"/>
        <source>GPSBabel Help</source>
        <translation>Справка GPSBabel</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="660"/>
        <source>About GPSBabel</source>
        <translation>О GPSBabel</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="665"/>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="670"/>
        <source>Preferences...</source>
        <translation>Настройки...</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="675"/>
        <source>Check for Upgrade</source>
        <translation>Проверить обновления</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="680"/>
        <source>Visit Website...</source>
        <translation>Посетите веб-сайт ...</translation>
    </message>
    <message>
        <location filename="mainwinui.ui" line="685"/>
        <source>Make a Donation...</source>
        <translation>Сделать пожертвование...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="263"/>
        <location filename="mainwindow.cpp" line="264"/>
        <source>default</source>
        <translation>по умолчанию</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="426"/>
        <source>Select one or more input files</source>
        <translation>Выберите один или несколько файлов</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="453"/>
        <source>Output File Name</source>
        <translation>Имя выходного файла</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="513"/>
        <source>Error reading format configuration.  Check that the backend program &quot;gpsbabel&quot; is properly installed and is in the current PATH

This program cannot continue.</source>
        <translation>Ошибка чтения конфигурации формата. Проверьте, что программа &quot;gpsbabel&quot; корректно установлена и путь до нее присутствет в переменной PATH

Выполнение программы не может быть продолжено.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="524"/>
        <source>Some file/device formats were not found during initialization.  Check that the backend program &quot;gpsbabel&quot; is properly installed and is in the current PATH

This program cannot continue.</source>
        <translation>Некоторые форматы файлов/устройств не были найдены в процессе инициализации. Проверьте, что программа &quot;gpsbabel&quot; корректно установлена и путь до нее присутствет в переменной PATH

Выполнение программы не может быть продолжено.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="546"/>
        <source>Input and output formats do not support %1</source>
        <translation>Входной и выходной форматы не поддерживают %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="549"/>
        <source>Input does not support %1; output format supports %2</source>
        <translation>Входной формат не поддерживает %1; выходной формат поддерживает %2</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="552"/>
        <source>Input format supports %1; output format does not support %2</source>
        <translation>Входной формат поддерживает %1; выходной формат не поддерживаетt %2</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="555"/>
        <source>Both input and output formats support %1</source>
        <translation>Входной и выходной формат поддерживают %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="576"/>
        <source>waypoints</source>
        <translation>маршрутные точки</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="577"/>
        <source>tracks</source>
        <translation>треки</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="578"/>
        <source>routes</source>
        <translation>маршруты</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="668"/>
        <source>There are no input options for format &quot;%1&quot;</source>
        <translation>Нет входных параметров для формата &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="675"/>
        <location filename="mainwindow.cpp" line="695"/>
        <source>Options for %1</source>
        <translation>Параметры %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="688"/>
        <source>There are no output options for format &quot;%1&quot;</source>
        <translation>Нет выходных параметров для формата &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="709"/>
        <source>No valid waypoints/routes/tracks translation specified</source>
        <translation>Не выбрано преобразование маршрутных точек/маршрутов/треков</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="728"/>
        <source>No input file specified</source>
        <translation>Не выбран входной файл</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="735"/>
        <source>No valid output specified</source>
        <translation>Не выбран выходной файл</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="740"/>
        <source>No output file specified</source>
        <translation>Не выбран выходной файл</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="756"/>
        <source>Process &quot;%1&quot; did not start</source>
        <translation>Процесс &quot;%1&quot; не запустился</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="770"/>
        <source>Process exited unsucessfully with code %1</source>
        <translation>Процесс завершился неудачей с кодом %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="913"/>
        <source>Translation successful</source>
        <translation>Конвертация выполнена</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="923"/>
        <source>Error running gpsbabel: %1
</source>
        <translation>Ошибка запуска gpsbabel: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1036"/>
        <source>Are you sure you want to reset all format options to default values?</source>
        <translation>Вы действительно желаете сбросить все параметры формата в значения по умолчанию?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1060"/>
        <source>About %1</source>
        <translation>О %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1103"/>
        <source>One or more data filters are active</source>
        <translation>Один или более фильтров данных активны</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1105"/>
        <source>No data filters are active</source>
        <translation>Фильтры данных не активны</translation>
    </message>
</context>
<context>
    <name>Map</name>
    <message>
        <location filename="map.cpp" line="66"/>
        <source>Missing &quot;gmapbase.html&quot; file.  Check installation</source>
        <translation>Отсутствует файл &quot;gmapbase.html&quot;. Попробуйте переустановить программу</translation>
    </message>
    <message>
        <location filename="map.cpp" line="86"/>
        <source>Failed to load Google maps base page</source>
        <translation>Не удалось загрузить базовую страницу Google Maps</translation>
    </message>
</context>
<context>
    <name>MiscFltWidget</name>
    <message>
        <location filename="miscfltui.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="27"/>
        <source>Misc. Filters</source>
        <translation>Прочие фильтры</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="34"/>
        <source>Nuke (Remove) Data Types</source>
        <translation>Очистить типы данных</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="46"/>
        <location filename="filterwidgets.cpp" line="222"/>
        <location filename="filterwidgets.cpp" line="223"/>
        <location filename="filterwidgets.cpp" line="224"/>
        <location filename="filterwidgets.cpp" line="225"/>
        <source>Routes</source>
        <translation>Маршруты</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="53"/>
        <location filename="filterwidgets.cpp" line="221"/>
        <location filename="filterwidgets.cpp" line="222"/>
        <location filename="filterwidgets.cpp" line="225"/>
        <location filename="filterwidgets.cpp" line="226"/>
        <source>Tracks</source>
        <translation>Треки</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="60"/>
        <location filename="filterwidgets.cpp" line="221"/>
        <location filename="filterwidgets.cpp" line="223"/>
        <location filename="filterwidgets.cpp" line="224"/>
        <location filename="filterwidgets.cpp" line="226"/>
        <source>Waypoints</source>
        <translation>Маршрутные точки</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="72"/>
        <source>Convert routes, waypoints and tracks to different types.</source>
        <translation>Преобразование маршрутов, маршрутных точек и треков в различные типы.</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="75"/>
        <source>This filter can be used to convert GPS data between different data types.

Some GPS data formats support only some subset of waypoints, tracks, and routes. The transform filter allows you to convert between these types. For example, it can be used to convert a pile of waypoints (such as those from a CSV file) into a track or vice versa. </source>
        <translation>Этот фильтр может быть использован для перевода данных GPS в различные типы.

Некоторые форматы данных GPS не предоставляют полную поддержку маршрутных точек, треков и маршрутов. Фильтр трансформации позволяет переводить данные между этими типами. Например, он может быть использован для конвертации точек (например из CSV файла) в трек и обратно.</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="80"/>
        <source>Transform</source>
        <translation>Трансформация</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="87"/>
        <source>Type of transformation. </source>
        <translation>Тип трансформации.</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="94"/>
        <source>Delete original data after transform to prevent duplicated data. </source>
        <translation>Удалить исходные данные после преобразования с целью предотвращения дублирования.</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="97"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="119"/>
        <source>Swap Longitude and Latitudes for badly formatted data formats.</source>
        <translation>Поменять местами долготу и широту для неправильно сформатированных форматов.</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="122"/>
        <source>Simple filter to swap the coordinate values (latitude and longitude) of all points. This can be helpful for wrong defined/coded data. Or if you think, you can use one of our xcsv formats, but latitude and longitude are in opposite order. </source>
        <translation>Простой фильтр для cмены местами координат (широта и долгота) всех точек. Может быть полезен для неправильно заданных/закодированных данных. Можно также использовать один из xcsv форматов, указав широту и долготу в обратном порядке.</translation>
    </message>
    <message>
        <location filename="miscfltui.ui" line="125"/>
        <source>Swap Coordinates</source>
        <translation>Поменять координаты местами</translation>
    </message>
</context>
<context>
    <name>OptionsDlg</name>
    <message>
        <location filename="optionsdlg.cpp" line="189"/>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="preferences.ui" line="20"/>
        <source>GPSBabel Preferences</source>
        <translation>Настройки GPSBabel</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="30"/>
        <source>General</source>
        <translation>Основные</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="45"/>
        <source>Check for newer version on start.</source>
        <translation>Проверять наличие свежей версии при старте.</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="52"/>
        <source>Anonymously report usage data.</source>
        <translation>Анонимно отправлять используемые данные.</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="59"/>
        <source>Ignore mismatch between command line and GUI version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="preferences.ui" line="68"/>
        <source>Formats</source>
        <translation>Форматы</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="76"/>
        <source>Enabled Formats</source>
        <translation>Доступные форматы</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="100"/>
        <source>Enable All</source>
        <translation>Включить все</translation>
    </message>
    <message>
        <location filename="preferences.ui" line="107"/>
        <source>Disable All</source>
        <translation>Отключить все</translation>
    </message>
</context>
<context>
    <name>ProcessWaitDialog</name>
    <message>
        <location filename="processwait.cpp" line="43"/>
        <source>Process failed to start</source>
        <translation>Неудача при запуске процесса</translation>
    </message>
    <message>
        <location filename="processwait.cpp" line="46"/>
        <source>Process crashed</source>
        <translation>Неудача</translation>
    </message>
    <message>
        <location filename="processwait.cpp" line="49"/>
        <source>Process timedout</source>
        <translation>Процесс остановлен</translation>
    </message>
    <message>
        <location filename="processwait.cpp" line="52"/>
        <source>Error while trying to write to process</source>
        <translation>Ошибка записи процесса</translation>
    </message>
    <message>
        <location filename="processwait.cpp" line="55"/>
        <source>Error while trying to read from process</source>
        <translation>Ошибка чтения процесса</translation>
    </message>
    <message>
        <location filename="processwait.cpp" line="59"/>
        <source>Unknown process error</source>
        <translation>Неизвестная ошибка</translation>
    </message>
    <message>
        <location filename="processwait.cpp" line="68"/>
        <source> ... Process GPSBabel</source>
        <translation>...GPSBabel Работает</translation>
    </message>
    <message>
        <location filename="processwait.cpp" line="83"/>
        <source>Stop Process</source>
        <translation>Остановить процесс</translation>
    </message>
    <message>
        <location filename="processwait.cpp" line="154"/>
        <source>Process did not terminate successfully</source>
        <translation>Процесс завершился неудачей</translation>
    </message>
    <message>
        <location filename="processwait.cpp" line="173"/>
        <source>Process crashed whle running</source>
        <translation>Неудача в процессе исполнения</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="formatload.cpp" line="155"/>
        <source>Error processing formats from running process &quot;gpsbabel -^3&quot; at line %1</source>
        <translation>Ошибка обработки форматов при запуске процесса &quot;gpsbabel -^3&quot; в строке %1</translation>
    </message>
</context>
<context>
    <name>RtTrkWidget</name>
    <message>
        <location filename="rttrkui.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="17"/>
        <source>Simplify routes and tracks by removing points</source>
        <translation>Упростить маршруты и треки путем удаления точек</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="20"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;The Simplify filter is used to simplify routes and tracks for use with formats that limit the number of points they can contain or just to reduce the complexity of a route. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;The filter attempts to remove points from each route until the number of points or the error is within the given bounds, while also attempting to preserve the shape of the original route as much as possible. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;The quality of the results will vary depending on the density of points in the original route and the length of the original route. &lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt; Фильтр упрощения используется для упрощения маршрутов и треков для использования с форматами, которые ограничивают количество точек или для уменьшения их сложности. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Фильтр пытается удалить точки из каждого маршрута, пока не достигается заданное число точек или ошибка. Одновременно он пытается сохранить форму оригинального маршрута насколько это возможно. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Качество результатов будет меняться в зависимости от плотности точек оригинального маршрута и его длины. &lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="40"/>
        <source>Routes &amp; Tracks</source>
        <translation>Маршруты и Треки</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="49"/>
        <source>Simplify route by removing points</source>
        <translation>Упростить маршрут путем удаления точек</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="52"/>
        <source> The Simplify filter is used to simplify routes and tracks for use with formats that limit the number of points they can contain or just to reduce the complexity of a route.

The filter attempts to remove points from each route until the number of points or the error is within the given bounds, while also attempting to preserve the shape of the original route as much as possible.

The quality of the results will vary depending on the density of points in the original route and the length of the original route. </source>
        <translation> Фильтр упрощения используется для упрощения маршрутов и треков для использования с форматами, которые ограничивают количество точек или для уменьшения их сложности.

Фильтр пытается удалить точки из каждого маршрута, пока не достигается заданное число точек или ошибка. Одновременно он пытается сохранить форму оригинального маршрута насколько это возможно.

Качество результатов будет меняться в зависимости от плотности точек оригинального маршрута и его длины. </translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="59"/>
        <source>Simplify</source>
        <translation>Упростить</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="82"/>
        <source>Limit To</source>
        <translation>Предел</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="89"/>
        <source>Maximum number points in track or route. </source>
        <translation>Максимальное количество точек в маршруте или треке.</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="96"/>
        <source>Points</source>
        <translation>Точек</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="118"/>
        <source>Reverse tracks and routes</source>
        <translation>Развернуть треки и маршруты</translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="121"/>
        <source>The reversal is performed in the laziest way possible. Timestamps are kept with the original waypoints so the resulting track or route will have the interesting characteristic that time runs backwards. This tends to make Magellan Mapsend, in particular, do a wierd thing and place each waypoint on a separate day. 
Additionally, if you&apos;re using this to reverse a route that navigates, say, an exit ramp or a one way street, you will be in for unpleasant ride. application cares about timestamps </source>
        <translation>Разворот производится самым примитивным путем. Оригинальные точки сохраняют временные метки, так что результирующий трек или маршрут будет идти назад во времени. Это может заставить некоторые приборы, такие как в особенности Magellan Mapsend, вести себя странным образом и помещать каждую точку в отдельный день.
Дополнительно, вы можете оказаться в неудобной ситуации, если используете такой маршрут для навигации по развязке или по улице с односторонним движением. Приложение следит за временными метками </translation>
    </message>
    <message>
        <location filename="rttrkui.ui" line="125"/>
        <source>Reverse</source>
        <translation>Развернуть</translation>
    </message>
</context>
<context>
    <name>TrackWidget</name>
    <message>
        <location filename="trackui.ui" line="14"/>
        <source>Track Filter Options</source>
        <translation>Параметры фильтра треков</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="17"/>
        <source>This filter performs various operations on track data. </source>
        <translation>Этот фильтр позволяет выполнить различные операции над треками.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="35"/>
        <source>Track Filters</source>
        <translation>Фильтр Треков</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="42"/>
        <source>Basic title for track</source>
        <translation>Простое название для новых треков</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="45"/>
        <source>Basic title for new track(s). 
This option specifies a title for tracks generated by the track filter. By default, the title of the new track is composed of the start time of the track appended to this value. 
If this value contains a percent (%) character, it is treated as a format string for the POSIX strftime function, allowing custom time-based track names. </source>
        <translation>Простое название для новых треков.
Этот параметр определяет название для треков, созданных фильтром треков. По умолчанию, к названию нового трека добавляется время начала трека.
Если это значение содержит знак процента (%), оно рассматривается как строка форматирования для функции POSIX strftime, позволяющей создавать названия треков, где время настроено пользователем.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="50"/>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="57"/>
        <source>the title of the new track is composed of the start time of the track appended to this value. </source>
        <translation>Название нового трека состоит из времени начала трека и этого значения.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="64"/>
        <source>Correct track point timestamps by specified amount</source>
        <translation>Скорректировать временные метки точек трека на заданную величину</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="67"/>
        <source>Correct trackpoint timestamps by a delta. 
This option changes the time of all trackpoints. This might be useful if your track must be moved by one or more hours because of an incorrect time zone. </source>
        <translation>Изменить временные метки на дельту.
Этот параметр изменяет время всех точек трека. Он может быть полезен, если вам нужно сместить время трека на неколько часов из-за неверной временной зоны.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="71"/>
        <source>Move</source>
        <translation>Сдвинуть</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="83"/>
        <location filename="trackui.ui" line="275"/>
        <source>days</source>
        <translation>дней</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="97"/>
        <source>hours</source>
        <translation>ч</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="111"/>
        <location filename="trackui.ui" line="265"/>
        <source>mins</source>
        <translation>мин</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="125"/>
        <source>secs</source>
        <translation>с</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="140"/>
        <location filename="trackui.ui" line="155"/>
        <source>Use track pts. after this time. </source>
        <translation>Использовать точки трека после этого времени.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="143"/>
        <source>Use only track points after this timestamp.

This option is used along with the stop to discard trackpoints that were recorded outside of a specific period of time. This option specifies the beginning of the time period. </source>
        <translation>Использовать только точки трека после этой временной метки.

Этот параметр используется вместе со временем окончания, чтобы удалить точки трека, полученные вне заданного временного диапазона. Этот параметр задает начало диапазона.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="148"/>
        <source>Start</source>
        <translation>Начало</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="162"/>
        <source>If checked, time specified here is based on this computer&apos;s current time zone. </source>
        <translation>Если включено, то время, указанное здесь, соответствует времени, указанному на компьютере.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="165"/>
        <source>If checked, the times specified here are based on the local computer&apos;s time zone.  Otherwise it is UTC.</source>
        <translation>Если включено, то время, указанное здесь, соответствует времени, указанному на компьютере. Иначе - UTC.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="168"/>
        <source>Local Time</source>
        <translation>Местное время</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="181"/>
        <location filename="trackui.ui" line="196"/>
        <source>Use track pts before this time. </source>
        <translation>Использовать точки трека до этого времени.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="184"/>
        <source> Use only track points before this timestamp.

This option is used in conjunction with the start option to discard all trackpoints outside of a given period of time. This option defines the end of the time period. </source>
        <translation>Использовать только точки трека до этой временной метки.

Этот параметр используется вместе со временем начала, чтобы удалить точки трека полученные вне заданного временного диапазона. Этот параметр задает конец диапазона.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="189"/>
        <source>Stop</source>
        <translation>Конец</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="203"/>
        <source>Pack all tracks into one. </source>
        <translation>Упаковать все треки в один.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="206"/>
        <source>Pack all tracks into one.

This option causes all tracks to be appended to one another to form a single track. This option does not work if any two tracks overlap in time; in that case, consider using the merge option.

This option is most useful for rejoining tracks that might have been interrupted by an equipment malfunction or an overnight stop. </source>
        <translation>Упаковать все треки в один.

Этот параметр заставляет все треки соединиться в единый трек. Этот параметр не работает, если два трека пересекаются во времени; в этом случае используйте опцию склеивания.

Полезен для объединения треков, которые могли быть разорваны из-за перебоев в работе прибора или остановки на ночь.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="213"/>
        <source>Pack</source>
        <translation>Упаковать</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="220"/>
        <source>Merge multiple tracks for the same way.</source>
        <translation>Склеить несколько треков для того же пути.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="223"/>
        <source> Merge multiple tracks for the same way.

This option puts all track points from all tracks into a single track and sorts them by time stamp. Points with identical time stamps will be dropped. </source>
        <translation>Склеить несколько треков для того же пути.

Этот параметр складывает все точки трека из всех треков в единый трек и сортирует их по временным меткам. Точки с одинаковыми метками - удаляются.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="228"/>
        <source>Merge</source>
        <translation>Склеить</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="235"/>
        <source>Split by Date</source>
        <translation>Разбить по дате</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="242"/>
        <source>Split by Time</source>
        <translation>Разбить по времени</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="254"/>
        <source>If nonzero, the track will be split if the time between two points is greater than this parameter.   If zero, the track will be split by date. </source>
        <translation>Если не 0, трек будет разбит если время между двумя точками больше, чем это значение. Если ноль, трек будет разбит по дате.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="270"/>
        <source>hrs</source>
        <translation>ч</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="285"/>
        <source>Split by Dist.</source>
        <translation>Разбить по расстоянию</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="297"/>
        <source>If nonzero, the input track will be split into several tracks if the distance between successive track points is greater than the distance given as a parameter. </source>
        <translation>Если не 0, исходный трек будет разбит на несколько треков если расстояние между последовательными точками больше, чем заданное.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="308"/>
        <source>ft</source>
        <translation>футов</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="313"/>
        <source>m</source>
        <translation>м</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="318"/>
        <source>km</source>
        <translation>км</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="323"/>
        <source>mi</source>
        <translation>миль</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="341"/>
        <source>GPS Fixes</source>
        <translation>GPS поправки</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="349"/>
        <source>none</source>
        <translation>нет</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="354"/>
        <source>pps</source>
        <translation></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="359"/>
        <source>dgps</source>
        <translation></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="364"/>
        <source>3d</source>
        <translation></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="369"/>
        <source>2d</source>
        <translation></translation>
    </message>
    <message>
        <location filename="trackui.ui" line="392"/>
        <source>Synthesize speed. </source>
        <translation>Синтезировать скорость.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="395"/>
        <source>Synthesize speed.

This option computes a value for the GPS speed at each trackpoint. This is most useful with trackpoints from formats that don&apos;t support speed information or for trackoints synthesized by the interpolate filter. The speed at each trackpoint is the average speed from the previous trackpoint (distance divided by time). The first trackpoint in each track is assigned a speed of &quot;unknown.&quot; </source>
        <translation>Синтезировать скорость.

Эта опция позволяет вычислить значение скорости в каждой точке трека. Это может понадобится для форматов, не поддерживающих скорость, или для точек, синтезированных фильтром интерполяции. Скорость в каждой точке является средней скоростью от предыдущей точки трека (расстояние, деленное на время). Первая точка каждого трека получает значение &quot;unknown.&quot;</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="400"/>
        <source>Speed</source>
        <translation>Скорость</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="407"/>
        <source>Synthesize course.</source>
        <translation>Синтезировать курс.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="410"/>
        <source>Synthesize course.

This option computes (or recomputes) a value for the GPS heading at each trackpoint. This is most useful with trackpoints from formats that don&apos;t support heading information or for trackpoints synthesized by the interpolate filter. The heading at each trackpoint is simply the course from the previous trackpoint in the track. The first trackpoint in each track is arbitrarily assigned a heading of 0 degrees. </source>
        <translation>Синтезировать курс.

Эта опция позволяет вычислить (или пересчитать) значение для курса GPS в каждой точке трека. Это может понадобится для форматов, не поддерживающих азимут или для точек, синтезированных фильтром интерполяции. Азимут в каждой точке является простым углом от предыдущей точки трека. Первая точка каждого трека получает значение 0 градусов.</translation>
    </message>
    <message>
        <location filename="trackui.ui" line="415"/>
        <source>Course</source>
        <translation>Курс</translation>
    </message>
</context>
<context>
    <name>Upgrade</name>
    <message>
        <location filename="upgrade.ui" line="14"/>
        <source>Dialog</source>
        <translation>Диалог</translation>
    </message>
</context>
<context>
    <name>UpgradeCheck</name>
    <message>
        <location filename="upgrade.cpp" line="207"/>
        <source>HTTP</source>
        <translation></translation>
    </message>
    <message>
        <location filename="upgrade.cpp" line="208"/>
        <source>Download failed: %1.</source>
        <translation>Загрузка завершилась неудачей: %1.</translation>
    </message>
    <message>
        <location filename="upgrade.cpp" line="237"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="upgrade.cpp" line="238"/>
        <source>Invalid return data at line %1: %2.</source>
        <translation>Некорректные данные возвращены в строке %1: %2.</translation>
    </message>
    <message>
        <location filename="upgrade.cpp" line="277"/>
        <source>A new version of GPSBabel is available.&lt;br /&gt;Your version is %1 &lt;br /&gt;The latest version is %2</source>
        <translation>Доступна новая версия GPSBabel.&lt;br /&gt;Используемая версия %1 &lt;br /&gt;Последняя доступная версия %2</translation>
    </message>
    <message>
        <location filename="upgrade.cpp" line="288"/>
        <source>Upgrade</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <location filename="upgrade.cpp" line="294"/>
        <source>Do you wish to download an upgrade?</source>
        <translation>Загрузить обновление?</translation>
    </message>
</context>
<context>
    <name>VersionMismatch</name>
    <message>
        <location filename="version_mismatch.ui" line="32"/>
        <source>GPSBabel Version Mismatch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="version_mismatch.ui" line="38"/>
        <source>&lt;b&gt;A version mismatch has been detected.&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="version_mismatch.ui" line="47"/>
        <source>GPSBabel command line version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="version_mismatch.ui" line="81"/>
        <source>GPSBabel GUI version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="version_mismatch.ui" line="115"/>
        <source>Never show this message again.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WayPtsWidget</name>
    <message>
        <location filename="wayptsui.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="29"/>
        <source>Waypoints Filters</source>
        <translation>Фильтр Маршрутных точек</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="36"/>
        <source>Remove duplicates</source>
        <translation>Удалить дубликаты</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="39"/>
        <source>The duplicate filter is designed to remove duplicate points based on their short name (traditionally a waypoint&apos;s name on the GPS receiver), and/or their location (to a precision of 6 decimals). This filter supports two options that specify how duplicates will be recognized, shortname and location. Generally, at least one of these options is required. </source>
        <translation>Фильтр дубликатов предназначен для того, чтобы убирать дублирующиеся точки используя информацию о их которком названии (обычно имя точки на приёмнике GPS), и/или их местоположении (с точностью до 6 знаков после запятой). Этот фильтр поддерживает две опции, которые указывают сколько дубликатов будет распознано, имя и местоположени. Обычно необходимо указать по крайней мере одну из этих опций.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="42"/>
        <source>Duplicates</source>
        <translation>Дубликаты</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="55"/>
        <source>Suppress duplicate waypoints based on name.</source>
        <translation>Предотвращать дублирование маршрутных точек с одинаковыми именами.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="58"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Suppress duplicate waypoints based on name. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;This option is the one most often used with the duplicate filter. This option instructs the duplicate filter to remove any waypoints that share a short name with a waypoint that has come before. This option might be used to remove duplicates if you are merging two datasets that were each created in part from a common ancestor dataset. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Предотвращать дублирование маршрутных точек с одинаковыми именами. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Этот параметр чаще всего используется с фильтром дубликатов. Он говорит фильтру убирать все точки, имеющие такое же имя, как и рассматриваемая точка. Может быть использован, чтобы удалять дубликаты при объединении двух наборов данных, созданных на основе общего источника.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="66"/>
        <source>Short Names</source>
        <translation>Короткие имена</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="73"/>
        <source>Suppress duplicate waypoint based on coords. </source>
        <translation>Предотвращать дублирование маршрутных точек с одинаковыми координатами.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="76"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Suppress duplicate waypoint based on coords. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;This option causes the duplicate filter to remove any additional waypoint that has the same coordinates (to six decimal degrees) as a waypoint that came before. This option may be used to remove duplicate waypoints if the names are not expected to be the same. It also might be used along with the &lt;span style=&quot; font-family:&apos;Courier New,courier&apos;;&quot;&gt;shortname&lt;/span&gt; option to remove duplicate waypoints if the names of several unrelated groups of waypoints might be the same. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Предотвращать дублирование маршрутных точек с одинаковыми координатами. &lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Этот параметр говорит фильтру дубликатов убирать любые дополнительные точки, имеющие такие же координаты (до 6 знаков после запятой) как и рассматриваемая точка. Может быть использован для очистки дубликатов, имеющих разные названия. Также может быть полезен вместе с параметром очистки по &lt;span style=&quot; font-family:&apos;Courier New,courier&apos;;&quot;&gt;именам&lt;/span&gt;, чтобы удалять дубликаты, если имена нескольких несвязанных групп точек могут быть одинаковыми. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="84"/>
        <source>Locations</source>
        <translation>Наложение</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="91"/>
        <source>Remove points based on proximity</source>
        <translation>Удалить точки, исходя из оценки их близости</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="94"/>
        <source>Maximum positional distance.

This option specifies the minimum allowable distance between two points. If two points are closer than this distance, only one of them is kept. </source>
        <translation>Максимальное позиционное расстояние.

Этот параметр определяет минимально допустимое расстояние между двумя точками. Если две точки ближе, чем это расстояние, одна из них удаляется.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="99"/>
        <source>Position</source>
        <translation>Положение</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="112"/>
        <source>Maximum positional distance.</source>
        <translation>Максимальное позиционное расстояние.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="120"/>
        <source>Feet</source>
        <translation>футов</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="125"/>
        <source>Meters</source>
        <translation>м</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="133"/>
        <source>Include points only within radius</source>
        <translation>Включать точки в пределах указанного радиуса</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="136"/>
        <source>This filter includes or excludes waypoints based on their proximity to a central point. All waypoints more than the specified distance from the specified point will be removed from the dataset.

By default, all remaining points are sorted so that points closer to the center appear earlier in the output file. </source>
        <translation>Этот фильтр включает или исключает маршрутные точки, на основе оценки близости к центральной точке. Все маршрутные точки, расстояние до которых больше указанного, будут удалены.

По умолчанию все оставшиеся точки отсортированы таким образом, что точки, расположенные ближе к центральной точке, будут идти первыми в выходном файле.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="141"/>
        <source>Radius</source>
        <translation>Радиус</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="154"/>
        <source>Maximum distance from center. </source>
        <translation>Максимальное расстояние от центра.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="162"/>
        <source>Miles</source>
        <translation>миль</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="167"/>
        <source>km</source>
        <translation>км</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="175"/>
        <source>Lat.</source>
        <translation>Широта</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="188"/>
        <source>Latitude of the central point in decimal degrees.  South latitudes should be expressed as a negative number.</source>
        <translation>Широта центральной точки в десятичных степенях. Южные широты должны быть выражены отрицательным числом.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="195"/>
        <source>Long.</source>
        <translation>Долгота</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="208"/>
        <source>Longitude of the central point in decimal degrees. West longitudes should be expressed as a negative number.</source>
        <translation>Долгота центральной точки в десятичных степенях. Западные долготы должны быть выражены отрицательным числом.</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="215"/>
        <location filename="wayptsui.ui" line="218"/>
        <source>This filter sorts waypoints into alphabetical order</source>
        <translation>Данный фильтр позволяет отсортировать маршрутные точки в алфавитном порядке</translation>
    </message>
    <message>
        <location filename="wayptsui.ui" line="221"/>
        <source>Sort</source>
        <translation>Сортировать</translation>
    </message>
</context>
</TS>
